@@ -20,7 +20,7 @@ Example:
   rgb = rawpipe.chroma_denoise(rgb)
   rgb = pipe.saturate(rgb, lambda x: x ** 0.75)
   rgb = rawpipe.gamma(rgb, "sRGB")
-  rgb = rawpipe.quantize(rgb, 255)
+  rgb = rawpipe.quantize8(rgb)
 
 Example:
   raw = rawpipe.verbose.linearize(raw)
@@ -38,5 +38,5 @@ _methods = [f for f in dir(Algorithms) if callable(getattr(Algorithms, f)) and n
 for m in _methods:
     globals()[m] = getattr(silent, m)
 
-__version__ = "0.9.7"
+__version__ = "0.9.9"
 __all__ = _methods
