@@ -75,7 +75,7 @@ class Algorithms:
             orgh, orgw = frame.shape[:2]
             if frame.ndim == 3:  # RGB mode
                 mode = "RGB"
-                frame = frame[::2*iterations, ::2*iterations]
+                frame = frame[::2**iterations, ::2**iterations]
             if frame.ndim == 2:  # Bayer mode
                 mode = "Bayer"
                 for _ in range(iterations):
@@ -156,7 +156,8 @@ class Algorithms:
         t0 = time.time()
         frame -= blacklevel
         frame /= whitelevel - blacklevel
-        self._vprint(f"{_elapsed(t0)} - linearizing from {minmax} to [{blacklevel:.2f}, {whitelevel:.2f}] to [0, 1]")
+        ranges = f"{minmax} => [{blacklevel:.2f}, {whitelevel:.2f}] => {self._minmax(frame)}"
+        self._vprint(f"{_elapsed(t0)} - linearizing: range = {ranges}")
         return frame
 
     def demosaic(self,
@@ -336,9 +337,10 @@ class Algorithms:
         In "LUT" mode, the frame is quantized to match the number of entries N
         in the look-up table; for example, if N=64, the output frame will have
         6-bit colors (and severe banding). This algorithm is format-agnostic.
-        If mode is None, the frame is returned untouched.
+        If mode evaluates to False, the frame is returned untouched.
         """
-        if mode is not None:
+        assert mode in ["sRGB", "rec709", "LUT"] or not mode, f"Unrecognized mode '{repr(mode)}'"
+        if mode in ["sRGB", "rec709", "LUT"]:
             t0 = time.time()
             realmode = mode
             input_range = self._minmax(frame)
@@ -366,7 +368,7 @@ class Algorithms:
                 frame = self._quantize(frame, maxval)  # [0, 1] ==> [0, maxval]
                 frame = lut[frame]                     # [0, maxval] ==> [0, maxval]
                 frame = frame / maxval                 # [0, maxval] ==> [0, 1]
-            self._vprint(f"{_elapsed(t0)} - applying gamma curve [{realmode}]: input range = {input_range}")
+            self._vprint(f"{_elapsed(t0)} - applying gamma curve [{realmode}]: range = {input_range} => {self._minmax(frame)}")
         return frame
 
     def quantize(self,
@@ -382,7 +384,23 @@ class Algorithms:
         input_range = self._minmax(frame)
         frame = np.clip(frame * maxval + 0.5, 0, maxval)
         frame = frame.astype(dtype)
-        self._vprint(f"{_elapsed(t0)} - quantizing from [0, 1] to {np.dtype(dtype).name} [0, {maxval}]; input range = {input_range}")
+        self._vprint(f"{_elapsed(t0)} - quantizing from [0, 1] to {np.dtype(dtype).name} [0, {maxval}]: input range = {input_range}")
+        return frame
+
+    def quantize8(self, frame: np.ndarray) -> np.ndarray:
+        """
+        Clip the given frame to [0, 1], rescale it to [0, 255], and convert it
+        to np.uint8. This algorithm is format-agnostic.
+        """
+        frame = self.quantize(frame, maxval=255, dtype=np.uint8)
+        return frame
+
+    def quantize16(self, frame: np.ndarray) -> np.ndarray:
+        """
+        Clip the given frame to [0, 1], rescale it to [0, 65535], and convert it
+        to np.uint16. This algorithm is format-agnostic.
+        """
+        frame = self.quantize(frame, maxval=65535, dtype=np.uint16)
         return frame
 
     def _quantize(self, frame: np.ndarray, maxval: int = 65535, dtype: np.dtype = np.uint16) -> np.ndarray:
